<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Core\Scripts
 * @copyright   Copyright (c) 2019, WeCodeArt Framework
 * @since 		1.9
 * @version		3.7.5
 */ 

namespace WeCodeArt\Core;

if ( ! defined( 'ABSPATH' ) ) exit();

/**
 * Framework Assets
 */
class Scripts {

	use \WeCodeArt\Singleton;

	/**
	 * Send to Constructor
	 * @since 3.6.2
	 */
	public function init() {
		// All starts here
		add_action( 'wp_enqueue_scripts', 	array( $this, 'front_scripts'  		) );
		add_action( 'wp_enqueue_scripts', 	array( $this, 'localize_js'			), 90 );
		add_action( 'wp_default_scripts', 	array( $this, 'jquery_to_footer'	) );
	}

	/**
	 * WeCodeArt JS Object
	 *
	 * @since	3.2
	 * @version	3.6.3
	 *
	 * @return 	void
	 */
	public function localize_js() {
		global $wp_scripts;

		$wecodeart = [
			'assetsEnqueue' 	=> $wp_scripts->queue, 
			'templateDirectory' => get_template_directory_uri()
		];
		if( is_child_theme() ) $wecodeart['styleDirectory'] = get_stylesheet_directory_uri();
		
		wp_localize_script( 'wecodeart-core', 'wecodeart', 
			apply_filters( 'wecodeart/filter/scripts/localize_js', $wecodeart ) 
		);
	}

	/**
	 * jQuery to Footer
	 *
	 * @since	3.1.2
	 * @version	3.5
	 */
	public function jquery_to_footer( $wp_scripts ) {
		if ( ! is_admin() && apply_filters( 'wecodeart/filter/scripts/jquery-in-footer', false ) ) {
			$wp_scripts->add_data( 'jquery', 			'group', 1 );
			$wp_scripts->add_data( 'jquery-core', 		'group', 1 );
			$wp_scripts->add_data( 'jquery-migrate', 	'group', 1 );
		}
	}

	/**
	 * Enqueue Front-End Styles
	 *
	 * @since	1.0
	 * @version	3.8.9
	 */
	public function front_scripts() {
		$folder = defined( WP_DEBUG ) && WP_DEBUG === true ? 'unminified' : 'minified';

		// Enqueue Styles
		wp_enqueue_style( 'wecodeart-core',	get_parent_theme_file_uri( '/assets/' . $folder . '/css/style.css' ), [], '3.7.5' );

		// Enqueue scripts
		wp_enqueue_script( 'wecodeart-core', get_parent_theme_file_uri( '/assets/' . $folder . '/js/frontend.js' ), [ 'jquery' ], '3.7.5', true );		
		if ( 
			( is_page() && comments_open() && get_option( 'thread_comments' ) ) || 
			( is_single() && comments_open() && get_option( 'thread_comments' ) ) 
		) wp_enqueue_script( 'comment-reply' );
	}
}